# PopSettings

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**access_window** | **str** | The range of messages which are accessible via POP. | [optional] 
**disposition** | **str** | The action that will be executed on a message after it has been fetched via POP. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

